@@ -1,7 +1,7 @@
-/** 
+/**
  * @copyright
  * ====================================================================
- * Copyright (c) 2000-2004 CollabNet.  All rights reserved.
+ * Copyright (c) 2000-2007 CollabNet.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -67,10 +67,13 @@ typedef struct svn_config_t svn_config_t;
 #define SVN_CONFIG_OPTION_HTTP_TIMEOUT              "http-timeout"
 #define SVN_CONFIG_OPTION_HTTP_COMPRESSION          "http-compression"
 #define SVN_CONFIG_OPTION_NEON_DEBUG_MASK           "neon-debug-mask"
+#define SVN_CONFIG_OPTION_HTTP_AUTH_TYPES           "http-auth-types"
 #define SVN_CONFIG_OPTION_SSL_AUTHORITY_FILES       "ssl-authority-files"
 #define SVN_CONFIG_OPTION_SSL_TRUST_DEFAULT_CA      "ssl-trust-default-ca"
 #define SVN_CONFIG_OPTION_SSL_CLIENT_CERT_FILE      "ssl-client-cert-file"
 #define SVN_CONFIG_OPTION_SSL_CLIENT_CERT_PASSWORD  "ssl-client-cert-password"
+#define SVN_CONFIG_OPTION_SSL_PKCS11_PROVIDER       "ssl-pkcs11-provider"
+#define SVN_CONFIG_OPTION_HTTP_LIBRARY              "http-library"
 
 #define SVN_CONFIG_CATEGORY_CONFIG          "config"
 #define SVN_CONFIG_SECTION_AUTH                 "auth"
@@ -81,6 +84,7 @@ typedef struct svn_config_t svn_config_t;
 #define SVN_CONFIG_OPTION_DIFF_CMD                  "diff-cmd"
 #define SVN_CONFIG_OPTION_DIFF3_CMD                 "diff3-cmd"
 #define SVN_CONFIG_OPTION_DIFF3_HAS_PROGRAM_ARG     "diff3-has-program-arg"
+#define SVN_CONFIG_OPTION_MERGE_TOOL_CMD            "merge-tool-cmd"
 #define SVN_CONFIG_SECTION_MISCELLANY           "miscellany"
 #define SVN_CONFIG_OPTION_GLOBAL_IGNORES            "global-ignores"
 #define SVN_CONFIG_OPTION_LOG_ENCODING              "log-encoding"
@@ -88,6 +92,9 @@ typedef struct svn_config_t svn_config_t;
 #define SVN_CONFIG_OPTION_TEMPLATE_ROOT             "template-root"
 #define SVN_CONFIG_OPTION_ENABLE_AUTO_PROPS         "enable-auto-props"
 #define SVN_CONFIG_OPTION_NO_UNLOCK                 "no-unlock"
+#define SVN_CONFIG_OPTION_MIMETYPES_FILE            "mime-types-file"
+#define SVN_CONFIG_OPTION_PRESERVED_CF_EXTS         "preserved-conflict-file-exts"
+#define SVN_CONFIG_OPTION_INTERACTIVE_CONFLICTS     "interactive-conflicts"
 #define SVN_CONFIG_SECTION_TUNNELS              "tunnels"
 #define SVN_CONFIG_SECTION_AUTO_PROPS           "auto-props"
 /** @} */
@@ -104,6 +111,10 @@ typedef struct svn_config_t svn_config_t;
 #define SVN_CONFIG_OPTION_PASSWORD_DB               "password-db"
 #define SVN_CONFIG_OPTION_REALM                     "realm"
 #define SVN_CONFIG_OPTION_AUTHZ_DB                  "authz-db"
+#define SVN_CONFIG_SECTION_SASL                 "sasl"
+#define SVN_CONFIG_OPTION_USE_SASL                  "use-sasl"
+#define SVN_CONFIG_OPTION_MIN_SSF                   "min-encryption"
+#define SVN_CONFIG_OPTION_MAX_SSF                   "max-encryption"
 
 /* For repository password database */
 #define SVN_CONFIG_SECTION_USERS                "users"
@@ -111,11 +122,21 @@ typedef struct svn_config_t svn_config_t;
 
 /*** Configuration Default Values ***/
 
-#define SVN_CONFIG_DEFAULT_GLOBAL_IGNORES \
-   "*.o *.lo *.la #*# .*.rej *.rej .*~ *~ .#* .DS_Store"
+/* '*' matches leading dots, e.g. '*.rej' matches '.foo.rej'. */
+/* We want this to be printed on two lines in the generated config file,
+ * but we don't want the # character to end up in the variable.
+ */
+#define SVN_CONFIG__DEFAULT_GLOBAL_IGNORES_LINE_1 \
+  "*.o *.lo *.la *.al .libs *.so *.so.[0-9]* *.a *.pyc *.pyo"
+#define SVN_CONFIG__DEFAULT_GLOBAL_IGNORES_LINE_2 \
+  "*.rej *~ #*# .#* .*.swp .DS_Store"
 
-#define SVN_CONFIG_TRUE  "true"
-#define SVN_CONFIG_FALSE "false"
+#define SVN_CONFIG_DEFAULT_GLOBAL_IGNORES \
+  SVN_CONFIG__DEFAULT_GLOBAL_IGNORES_LINE_1 " " \
+  SVN_CONFIG__DEFAULT_GLOBAL_IGNORES_LINE_2
+
+#define SVN_CONFIG_TRUE  "TRUE"
+#define SVN_CONFIG_FALSE "FALSE"
 
 
 /** Read configuration information from the standard sources and merge it
@@ -130,11 +151,11 @@ typedef struct svn_config_t svn_config_t;
  * categories (@c SVN_CONFIG_CATEGORY_SERVERS,
  * @c SVN_CONFIG_CATEGORY_CONFIG, etc.) and whose values are the @c
  * svn_config_t * items representing the configuration values for that
- * category.  
+ * category.
  */
-svn_error_t *svn_config_get_config (apr_hash_t **cfg_hash,
-                                    const char *config_dir,
-                                    apr_pool_t *pool);
+svn_error_t *svn_config_get_config(apr_hash_t **cfg_hash,
+                                   const char *config_dir,
+                                   apr_pool_t *pool);
 
 
 /** Read configuration data from @a file (a file or registry path) into
@@ -143,10 +164,10 @@ svn_error_t *svn_config_get_config (apr_hash_t **cfg_hash,
  * If @a file does not exist, then if @a must_exist, return an error,
  * otherwise return an empty @c svn_config_t.
  */
-svn_error_t *svn_config_read (svn_config_t **cfgp,
-                              const char *file,
-                              svn_boolean_t must_exist,
-                              apr_pool_t *pool);
+svn_error_t *svn_config_read(svn_config_t **cfgp,
+                             const char *file,
+                             svn_boolean_t must_exist,
+                             apr_pool_t *pool);
 
 /** Like svn_config_read(), but merges the configuration data from @a file
  * (a file or registry path) into @a *cfg, which was previously returned
@@ -154,12 +175,12 @@ svn_error_t *svn_config_read (svn_config_t **cfgp,
  * expansions in @a cfg, so that the next svn_config_get() takes the
  * modifications into account.
  */
-svn_error_t *svn_config_merge (svn_config_t *cfg,
-                               const char *file,
-                               svn_boolean_t must_exist);
+svn_error_t *svn_config_merge(svn_config_t *cfg,
+                              const char *file,
+                              svn_boolean_t must_exist);
 
 
-/** Find the value of a (@a section, @a option) pair in @a cfg, set @a 
+/** Find the value of a (@a section, @a option) pair in @a cfg, set @a
  * *valuep to the value.
  *
  * If @a cfg is @c NULL, just sets @a *valuep to @a default_value. If
@@ -172,36 +193,38 @@ svn_error_t *svn_config_merge (svn_config_t *cfg,
  *
  * This function may change @a cfg by expanding option values.
  */
-void svn_config_get (svn_config_t *cfg, const char **valuep,
-                     const char *section, const char *option,
-                     const char *default_value);
+void svn_config_get(svn_config_t *cfg, const char **valuep,
+                    const char *section, const char *option,
+                    const char *default_value);
 
-/** Add or replace the value of a (@a section, @a option) pair in @a cfg with 
+/** Add or replace the value of a (@a section, @a option) pair in @a cfg with
  * @a value.
  *
  * This function invalidates all value expansions in @a cfg.
+ *
+ * To remove an option, pass NULL for the @c value.
  */
-void svn_config_set (svn_config_t *cfg,
-                     const char *section, const char *option,
-                     const char *value);
+void svn_config_set(svn_config_t *cfg,
+                    const char *section, const char *option,
+                    const char *value);
 
 /** Like svn_config_get(), but for boolean values.
  *
  * Parses the option as a boolean value. The recognized representations
- * are 'true'/'false', 'yes'/'no', 'on'/'off', '1'/'0'; case does not
+ * are 'TRUE'/'FALSE', 'yes'/'no', 'on'/'off', '1'/'0'; case does not
  * matter. Returns an error if the option doesn't contain a known string.
  */
-svn_error_t *svn_config_get_bool (svn_config_t *cfg, svn_boolean_t *valuep,
-                                  const char *section, const char *option,
-                                  svn_boolean_t default_value);
+svn_error_t *svn_config_get_bool(svn_config_t *cfg, svn_boolean_t *valuep,
+                                 const char *section, const char *option,
+                                 svn_boolean_t default_value);
 
 /** Like svn_config_set(), but for boolean values.
  *
- * Sets the option to 'true'/'false', depending on @a value.
+ * Sets the option to 'TRUE'/'FALSE', depending on @a value.
  */
-void svn_config_set_bool (svn_config_t *cfg,
-                          const char *section, const char *option,
-                          svn_boolean_t value);
+void svn_config_set_bool(svn_config_t *cfg,
+                         const char *section, const char *option,
+                         svn_boolean_t value);
 
 /** Similar to @c svn_config_section_enumerator2_t, but is not
  * provided with a memory pool argument.
@@ -210,17 +233,17 @@ void svn_config_set_bool (svn_config_t *cfg,
  *
  * @deprecated Provided for backwards compatibility with the 1.2 API.
  */
-typedef svn_boolean_t (*svn_config_section_enumerator_t)
-       (const char *name, void *baton);
+typedef svn_boolean_t (*svn_config_section_enumerator_t)(const char *name,
+                                                         void *baton);
 
-/** Similar to svn_config_enumerate_sections2(), but uses a memory pool of 
+/** Similar to svn_config_enumerate_sections2(), but uses a memory pool of
  * @a cfg instead of one that is explicitely provided.
  *
- * @deprecated Provided for backwards compatibility with the 1.2 API. 
+ * @deprecated Provided for backwards compatibility with the 1.2 API.
  */
-int svn_config_enumerate_sections (svn_config_t *cfg, 
-                                   svn_config_section_enumerator_t callback,
-                                   void *baton);
+int svn_config_enumerate_sections(svn_config_t *cfg,
+                                  svn_config_section_enumerator_t callback,
+                                  void *baton);
 
 /** A callback function used in enumerating config sections.
  *
@@ -228,41 +251,42 @@ int svn_config_enumerate_sections (svn_config_t *cfg,
  *
  * @since New in 1.3.
  */
-typedef svn_boolean_t (*svn_config_section_enumerator2_t)
-       (const char *name, void *baton, apr_pool_t *pool);
+typedef svn_boolean_t (*svn_config_section_enumerator2_t)(const char *name,
+                                                          void *baton,
+                                                          apr_pool_t *pool);
 
 /** Enumerate the sections, passing @a baton and the current section's name
  * to @a callback.  Continue the enumeration if @a callback returns @c TRUE.
- * Return the number of times @a callback was called. 
+ * Return the number of times @a callback was called.
  *
  * ### See kff's comment to svn_config_enumerate2().  It applies to this
  * function, too. ###
  *
- * @a callback's @a name and @a name parameters are only valid for the
- * duration of the call.
+ * @a callback's @a name parameter is only valid for the duration of the call.
  *
  * @since New in 1.3.
  */
-int svn_config_enumerate_sections2 (svn_config_t *cfg, 
-                                    svn_config_section_enumerator2_t callback,
-                                    void *baton, apr_pool_t *pool);
+int svn_config_enumerate_sections2(svn_config_t *cfg,
+                                   svn_config_section_enumerator2_t callback,
+                                   void *baton, apr_pool_t *pool);
 
 /** Similar to @c svn_config_enumerator2_t, but is not
  * provided with a memory pool argument.
  * See svn_config_enumerate() for the details of this type.
  *
- * @deprecated Provided for backwards compatibility with the 1.2 API. 
+ * @deprecated Provided for backwards compatibility with the 1.2 API.
  */
-typedef svn_boolean_t (*svn_config_enumerator_t)
-       (const char *name, const char *value, void *baton);
+typedef svn_boolean_t (*svn_config_enumerator_t)(const char *name,
+                                                 const char *value,
+                                                 void *baton);
 
-/** Similar to svn_config_enumerate2(), but uses a memory pool of 
+/** Similar to svn_config_enumerate2(), but uses a memory pool of
  * @a cfg instead of one that is explicitely provided.
  *
- * @deprecated Provided for backwards compatibility with the 1.2 API. 
+ * @deprecated Provided for backwards compatibility with the 1.2 API.
  */
-int svn_config_enumerate (svn_config_t *cfg, const char *section,
-                          svn_config_enumerator_t callback, void *baton);
+int svn_config_enumerate(svn_config_t *cfg, const char *section,
+                         svn_config_enumerator_t callback, void *baton);
 
 
 /** A callback function used in enumerating config options.
@@ -271,12 +295,14 @@ int svn_config_enumerate (svn_config_t *cfg, const char *section,
  *
  * @since New in 1.3.
  */
-typedef svn_boolean_t (*svn_config_enumerator2_t)
-       (const char *name, const char *value, void *baton, apr_pool_t *pool);
+typedef svn_boolean_t (*svn_config_enumerator2_t)(const char *name,
+                                                  const char *value,
+                                                  void *baton,
+                                                  apr_pool_t *pool);
 
 /** Enumerate the options in @a section, passing @a baton and the current
  * option's name and value to @a callback.  Continue the enumeration if
- * @a callback returns @c TRUE.  Return the number of times @a callback 
+ * @a callback returns @c TRUE.  Return the number of times @a callback
  * was called.
  *
  * ### kff asks: A more usual interface is to continue enumerating
@@ -292,19 +318,25 @@ typedef svn_boolean_t (*svn_config_enumerator2_t)
  *
  * @since New in 1.3.
  */
-int svn_config_enumerate2 (svn_config_t *cfg, const char *section,
-                           svn_config_enumerator2_t callback, void *baton,
-                           apr_pool_t *pool);
+int svn_config_enumerate2(svn_config_t *cfg, const char *section,
+                          svn_config_enumerator2_t callback, void *baton,
+                          apr_pool_t *pool);
 
+/**
+ * Return @c TRUE if @a section exists in @a cfg, @c FALSE otherwise.
+ *
+ * @since New in 1.4.
+ */
+svn_boolean_t svn_config_has_section(svn_config_t *cfg, const char *section);
 
 /** Enumerate the group @a master_section in @a cfg.  Each variable
  * value is interpreted as a list of glob patterns (separated by comma
  * and optional whitespace).  Return the name of the first variable
  * whose value matches @a key, or @c NULL if no variable matches.
  */
-const char *svn_config_find_group (svn_config_t *cfg, const char *key,
-                                   const char *master_section,
-                                   apr_pool_t *pool);
+const char *svn_config_find_group(svn_config_t *cfg, const char *key,
+                                  const char *master_section,
+                                  apr_pool_t *pool);
 
 /** Retrieve value corresponding to @a option_name for a given
  *  @a server_group in @a cfg , or return @a default_value if none is found.
@@ -335,26 +367,26 @@ svn_error_t *svn_config_get_server_setting_int(svn_config_t *cfg,
 
 /** Try to ensure that the user's ~/.subversion/ area exists, and create
  * no-op template files for any absent config files.  Use @a pool for any
- * temporary allocation.  If @a config_dir is not NULL it specifies a
+ * temporary allocation.  If @a config_dir is not @c NULL it specifies a
  * directory from which to read the config overriding all other sources.
  *
  * Don't error if something exists but is the wrong kind (for example,
  * ~/.subversion exists but is a file, or ~/.subversion/servers exists
  * but is a directory).
  *
- * Also don't error if try to create something and fail -- it's okay
- * for the config area or its contents not to be created.  But if
- * succeed in creating a config template file, return error if unable
- * to initialize its contents.
+ * Also don't error if trying to create something and failing -- it's
+ * okay for the config area or its contents not to be created.
+ * However, if creating a config template file succeeds, return an
+ * error if unable to initialize its contents.
  */
-svn_error_t *svn_config_ensure (const char *config_dir, apr_pool_t *pool);
+svn_error_t *svn_config_ensure(const char *config_dir, apr_pool_t *pool);
 
 
 
 
 /** Accessing cached authentication data in the user config area.
  *
- * @defgroup cached_authentication_data cached authentication data.
+ * @defgroup cached_authentication_data Cached authentication data
  * @{
  */
 
@@ -379,11 +411,11 @@ svn_error_t *svn_config_ensure (const char *config_dir, apr_pool_t *pool);
  * The hashtable will contain <tt>const char *</tt> keys and
  * <tt>svn_string_t *</tt> values.
  */
-svn_error_t * svn_config_read_auth_data (apr_hash_t **hash,
-                                         const char *cred_kind,
-                                         const char *realmstring,
-                                         const char *config_dir,
-                                         apr_pool_t *pool);
+svn_error_t * svn_config_read_auth_data(apr_hash_t **hash,
+                                        const char *cred_kind,
+                                        const char *realmstring,
+                                        const char *config_dir,
+                                        apr_pool_t *pool);
 
 /** Use @a cred_kind and @a realmstring to create or overwrite a file
  * within the ~/.subversion/auth/ area.  Write the contents of @a hash into
@@ -397,11 +429,11 @@ svn_error_t * svn_config_read_auth_data (apr_hash_t **hash,
  * The hashtable must contain <tt>const char *</tt> keys and
  * <tt>svn_string_t *</tt> values.
  */
-svn_error_t * svn_config_write_auth_data (apr_hash_t *hash,
-                                          const char *cred_kind,
-                                          const char *realmstring,
-                                          const char *config_dir,
-                                          apr_pool_t *pool);
+svn_error_t * svn_config_write_auth_data(apr_hash_t *hash,
+                                         const char *cred_kind,
+                                         const char *realmstring,
+                                         const char *config_dir,
+                                         apr_pool_t *pool);
 
 /** @} */
 
